traitsui\.tests\.ui\_editors\.test\_data\_frame\_editor module
==============================================================

.. automodule:: traitsui.tests.ui_editors.test_data_frame_editor
    :members:
    :undoc-members:
    :show-inheritance:
